@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -30,8 +30,9 @@ sub layout          { Spreadsheet::HTML::Presets::layout(           @_ ) }
 sub handson         { Spreadsheet::HTML::Presets::Handson::handson( @_ ) }
 sub conway          { Spreadsheet::HTML::Presets::Conway::conway(   @_ ) }
 sub calculator      { Spreadsheet::HTML::Presets::Calculator::calculator( @_ ) }
-sub chess           { Spreadsheet::HTML::Presets::chess(            @_ ) }
+sub chess           { Spreadsheet::HTML::Presets::Chess::chess(     @_ ) }
 sub checkers        { Spreadsheet::HTML::Presets::checkers(         @_ ) }
+sub tictactoe       { Spreadsheet::HTML::Presets::TicTacToe::tictactoe( @_ ) }
 sub sudoku          { Spreadsheet::HTML::Presets::Sudoku::sudoku(   @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard(     @_ ) }
 sub calendar        { Spreadsheet::HTML::Presets::calendar(         @_ ) }
@@ -289,7 +290,7 @@ sub _args {
     return ( $self, $self->{data}, $args ) if $self and $self->{is_cached};
 
     $args->{worksheet} ||= 1;
-    $data = Spreadsheet::HTML::File::Loader::parse( $args ) if $args->{file};
+    $data = Spreadsheet::HTML::File::Loader::_parse( $args ) if $args->{file};
     $data = [ $data ] unless ref($data);
     $data = [ $data ] unless ref($data->[0]);
 
@@ -407,7 +408,7 @@ Run C<mktable --man> for more documentation.
 
 =item * C<benchmark-spreadsheet-html>
 
-This tool runs benchmarks against several different HTML table generators
+Run benchmarks against several different HTML table generators
 available on CPAN. See C<benchmark-spreadsheet-html --man> for more.
 
 =back
@@ -635,14 +636,13 @@ Useful for loading data from files only once.
 
 =item * C<matrix: 0 or 1>
 
-Treat headings as a regular row. Render the table with
-only td tags, no th tags.
+Render the headings row with only <td> tags, no <th> tags.
 
 =item * C<headless: 0 or 1>
 
 Render the table with without the headings row at all. 
-The first row after the headings is still C<-r1>, thus
-any reference to C<headings> will be discarded too.
+The first row after the headings is still C<-r1>, and
+any configuration to C<headings> or C<-r0> will be discarded.
 
 =item * C<animate: 0 or 1>
 
@@ -842,12 +842,14 @@ with little to no additional coding.
 
 =item * C<checkers( %params )>
 
+=item * C<tictactoe( %params )>
+
 =item * C<beadwork( %params )>
 
 =back
 
-See L<Spreadsheet::HTML::Presets> for more documentation (and the source
-for more usage examples).
+See L<Spreadsheet::HTML::Presets> for more documentation (and its source
+code for usage examples).
 
 =head1 REQUIRES
 
@@ -947,16 +949,14 @@ Please report any bugs or feature requests to either
 I will be notified, and then you'll automatically be notified of progress
 on your bug as I make changes.
 
-=head1 GITHUB
-
-The Github project is L<https://github.com/jeffa/Spreadsheet-HTML>
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Spreadsheet::HTML
 
+The Github project is L<https://github.com/jeffa/Spreadsheet-HTML>
+
 You can also look for information at:
 
 =over 4
