@@ -6,17 +6,17 @@ use warnings FATAL => 'all';
 eval "use Spreadsheet::Read";
 our $NOT_AVAILABLE = $@;
 
-sub parse {
+sub _parse {
     my $args     = shift;
     my $file     = $args->{file};
     my $preserve = $args->{preserve};
 
     if ($file =~ /\.html?$/) {
-        return Spreadsheet::HTML::File::HTML::parse( $args );
+        return Spreadsheet::HTML::File::HTML::_parse( $args );
     } elsif ($file =~ /\.jso?n$/) {
-        return Spreadsheet::HTML::File::JSON::parse( $args );
+        return Spreadsheet::HTML::File::JSON::_parse( $args );
     } elsif ($file =~ /\.ya?ml$/) {
-        return Spreadsheet::HTML::File::YAML::parse( $args );
+        return Spreadsheet::HTML::File::YAML::_parse( $args );
     }
 
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
@@ -66,39 +66,39 @@ sub _attr_map {(
 
 Spreadsheet::HTML::File::Loader - Load data from files.
 
+=head1 DESCRIPTION
+
+This is a container for L<Spreadsheet::HTML> file loading methods.
+These package is not meant to be directly used. Instead, use the
+Spreadsheet::HTML interface:
+
+  use Spreadsheet::HTML;
+  my $generator = Spreadsheet::HTML->new( file => 'foo.xls' );
+  print $generator->generate();
+
+  # or
+  use Spreadsheet::HTML qw( generate );
+  print generate( file => 'foo.xls' );
+
 =head1 SUPPORTED FORMATS
 
 =over 4
 
 =item * CSV/XLS
 
-Parses with L<Spreadsheet::Read>.
+Parses with (requires) L<Spreadsheet::Read>.
 
 =item * HTML
 
-Parses with L<HTML::TableExtract>.
+Parses with (requires) L<HTML::TableExtract>.
 
 =item * JSON
 
-Parses with L<JSON>.
+Parses with (requires) L<JSON>.
 
 =item * YAML
 
-Parses with L<YAML>.
-
-=back
-
-=head1 BEGIN REQUISITE DOCUMENTATION
-
-The rest of this document exists to make POD tests happy. 
-
-You may stop reading now :)
-
-=head1 METHODS
-
-=over 4
-
-=item * C<parse( \%args )>
+Parses with (requires) L<YAML>.
 
 =back
 
@@ -109,29 +109,6 @@ You may stop reading now :)
 
 
 package Spreadsheet::HTML::File::YAML;
-=head1 NAME
-
-Spreadsheet::HTML::File::YAML - Load data from YAML encoded data files.
-
-=head1 METHODS
-
-=over 4
-
-=item * C<parse()>
-=item * C<parse( \%args )>
-
-=back
-
-=head1 REQUIRES
-
-=over 4
-
-=item * L<YAML>
-
-=back
-
-=cut
-
 use Carp;
 use strict;
 use warnings FATAL => 'all';
@@ -139,7 +116,7 @@ use warnings FATAL => 'all';
 eval "use YAML";
 our $NOT_AVAILABLE = $@;
 
-sub parse {
+sub _parse {
     my $args = shift;
     my $file = $args->{file};
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
@@ -154,28 +131,6 @@ sub parse {
 
 
 package Spreadsheet::HTML::File::JSON;
-=head1 NAME
-
-Spreadsheet::HTML::File::JSON - Load data from JSON encoded data files.
-
-=head1 METHODS
-
-=over 4
-
-=item * C<parse( \%args )>
-
-=back
-
-=head1 REQUIRES
-
-=over 4
-
-=item * L<JSON>
-
-=back
-
-=cut
-
 use Carp;
 use strict;
 use warnings FATAL => 'all';
@@ -183,7 +138,7 @@ use warnings FATAL => 'all';
 eval "use JSON";
 our $NOT_AVAILABLE = $@;
 
-sub parse {
+sub _parse {
     my $args = shift;
     my $file = $args->{file};
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
@@ -200,28 +155,6 @@ sub parse {
 
 
 package Spreadsheet::HTML::File::HTML;
-=head1 NAME
-
-Spreadsheet::HTML::File::HTML - Load data from Hypertext Markup files.
-
-=head1 METHODS
-
-=over 4
-
-=item * C<parse( \%args )>
-
-=back
-
-=head1 REQUIRES
-
-=over 4
-
-=item * L<HTML::TableExtract>
-
-=back
-
-=cut
-
 use Carp;
 use strict;
 use warnings FATAL => 'all';
@@ -229,7 +162,7 @@ use warnings FATAL => 'all';
 eval "use HTML::TableExtract";
 our $NOT_AVAILABLE = $@;
 
-sub parse {
+sub _parse {
     my $args = shift;
     my $file = $args->{file};
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
@@ -289,6 +222,7 @@ YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
 CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 =cut
 
 1;
